# -*- coding: UTF-8 -*-
# Copyright 2002-2016 Luc Saffre
# License: BSD (see file COPYING for details)

"""The :mod:`lino_book` package contains a set of example projects
used both for testing and explaining Lino framework.

.. autosummary::
   :toctree:

   projects

"""

from __future__ import unicode_literals
from __future__ import absolute_import

from os.path import join, dirname

filename = join(dirname(__file__), 'setup_info.py')
exec(compile(open(filename, "rb").read(), filename, 'exec'))

# above line is equivalent to "execfile(filename)", except that it
# works also in Python 3

__version__ = SETUP_INFO['version']
intersphinx_urls = dict(docs="http://www.lino-framework.org")
srcref_url = 'https://github.com/lsaffre/book/blob/master/%s'




# -*- coding: UTF-8 -*-
# Copyright 2012-2016 Luc Saffre
# License: BSD (see file COPYING for details)
"""
This is the base for all settings of lino.projects.min1

.. autosummary::
   :toctree:

   demo


"""

from lino.projects.std.settings import *


class Site(Site):
    title = "Lino Mini 1"

    demo_fixtures = 'std demo demo2'

    user_profiles_module = 'lino.modlib.office.roles'

    workflows_module = 'lino_xl.lib.cal.workflows.take'

    def setup_quicklinks(self, ar, tb):
        tb.add_action(self.modules.contacts.Persons.detail_action)
        tb.add_action(self.modules.contacts.Companies.detail_action)

    def get_installed_apps(self):
        yield super(Site, self).get_installed_apps()

        yield 'lino.modlib.system'
        yield 'lino.modlib.users'
        yield 'lino_xl.lib.contacts'
        yield 'lino_xl.lib.cal'
        yield 'lino.modlib.export_excel'

    def get_admin_main_items(self, ar):
        yield self.modules.cal.MyEvents




from lino.api import ad
from lino_book.projects.min2.settings import *
from lino.utils import i2d

# ad.configure_plugin('sepa', import_statements_path="/home/khchine5/Documents/Documentation/Lino/Ticket 505/test_file")

SITE = Site(globals(), the_demo_date=i2d(20141023))
ALLOWED_HOSTS = ['*']
DEBUG = True
SECRET_KEY = "20227"  # see :djangoticket:`20227`



# -*- coding: UTF-8 -*-
# Copyright 2016 Luc Saffre
# License: BSD (see file COPYING for details)

"""Database models for `lino_book.projects.dumps`.

"""

from django.db import models
from lino.api import _
from lino.mixins import BabelNamed


class Foo(BabelNamed):

    class Meta(object):
        app_label = 'dumps'
        verbose_name = _("Foo")
        verbose_name_plural = _("Foos")

    last_visit = models.DateTimeField(_("Last visit"), editable=False)

    



"""A minimal application used by a number of tests and tutorials. It
is not meant to be actually useful in the real world.

It uses the following plugins:

- 
- :mod:`lino.modlib.system`
- :mod:`lino.modlib.users`
- :mod:`lino_xl.lib.contacts` (which needs :mod:`lino_xl.lib.countries`)
- :mod:`lino_xl.lib.cal` (which needs :mod:`lino.modlib.gfks`)
- :mod:`lino.modlib.export_excel`

.. autosummary::
   :toctree:

   settings


"""



from __future__ import unicode_literals

from django.db import models
from lino.api import dd


@dd.python_2_unicode_compatible
class Person(dd.Model):
    name = models.CharField(max_length=50)

    def __str__(self):
        return self.name


@ddpython_2_unicode_compatible
class Place(dd.Model):
    name = models.CharField(max_length=50)
    owners = models.ManyToManyField(Person, related_name="owned_places")
    ceo = models.ForeignKey(Person, related_name="managed_places")

    def __str__(self):
        if self.get_restaurant():
            if self.get_bar():
                what = "Restaurant & Bar "
            else:
                what = "Restaurant "
        elif self.get_bar():
            what = "Bar "
        else:
            what = ''
        return "%s %s(ceo=%s,owners=%s)" % (
            self.name, what, self.ceo,
            ','.join([unicode(o) for o in self.owners.all()]))

    def get_restaurant(self):
        try:
            return self.restaurant
        except Restaurant.DoesNotExist:
            return None

    def get_bar(self):
        try:
            return self.bar
        except Bar.DoesNotExist:
            return None


@dd.python_2_unicode_compatible
class Bar(dd.Model):
    place = models.OneToOneField(Place)
    serves_alcohol = models.BooleanField(default=True)

    def __str__(self):
        if self.serves_alcohol:
            return self.place.name
        return "%s (no alcohol)" % self.place.name


@dd.python_2_unicode_compatible
class Restaurant(dd.Model):
    place = models.OneToOneField(Place)
    serves_hot_dogs = models.BooleanField(default=False)
    cooks = models.ManyToManyField(Person)

    def __str__(self):
        return "%s (cooks=%s)" % (
            self.place.name,
            ','.join([unicode(o) for o in self.cooks.all()]))



"""This package contains example applications included with Lino.

See also :doc:`/tutorials/hello/index` which explains how to try them
out.

Examples with their own documentation entry:

- :mod:`lino_book.projects.belref` ---
  See :ref:`belref`
- :mod:`lino_book.projects.polly`
  See :ref:`polly`

Poorly documented examples at different development states:

.. autosummary::
   :toctree:

   min1
   min2
   max
   dumps
   events
   cms
   crl
   homeworkschool
   igen
   i18n


Examples covered by a tutorial:

- :mod:`lino_book.projects.babel_tutorial` ---
  See :ref:`mldbc_tutorial`

Technical

.. autosummary::
   :toctree:

   docs
   belref
   estref


"""




# -*- coding: UTF-8 -*-
# Copyright 2013-2015 Luc Saffre
# License: BSD (see file COPYING for details)

"""
Default settings module for a :ref:`polly` project.
"""

from __future__ import unicode_literals

from lino.projects.std.settings import *

from django.utils.translation import ugettext_lazy as _


class Site(Site):

    """
    Base class for a :ref:`polly` application,
    designed to be instantiated into the :setting:`SITE` setting.
    """

    verbose_name = "Lino Polly"
    description = _("a Lino application to make surveys and polls.")
    version = "0.1"
    url = "http://www.lino-framework.org/examples/polly"
    author = 'Luc Saffre'
    author_email = 'luc.saffre@gmail.com'

    demo_fixtures = 'std demo feedback demo2'.split()
    user_profiles_module = 'lino_xl.lib.polls.roles'

    languages = 'en de et'

    def get_installed_apps(self):
        yield super(Site, self).get_installed_apps()
        yield 'lino.modlib.gfks'
        # yield 'lino.modlib.system'
        yield 'lino.modlib.users'
        #~ yield 'lino_xl.lib.countries'
        #~ yield 'lino_xl.lib.properties'
        #~ yield 'lino.modlib.' + self.partners_app_label
        #~ yield 'lino_xl.lib.households'
        yield 'lino_xl.lib.polls'
        #~ yield 'lino_xl.lib.pages'
        #~ yield 'lino.projects.polly'
        # yield 'lino_xl.lib.appypod'



# -*- coding: UTF-8 -*-
# Copyright 2009-2016 Luc Saffre
# License: BSD (see file COPYING for details)

#~ Note that this module may not have a docstring because any
#~ global variable defined here will override the global
#~ namespace of lino/__init__.py who includes it with execfile.

# This module is part of the Lino test suite.
# To test only this module:
#
#   $ python setup.py test -s tests.PackagesTests

from __future__ import unicode_literals
import sys
PY2 = sys.version_info[0] == 2
PY3 = sys.version_info[0] == 3

SETUP_INFO = dict(
    name='lino_book',
    version='1.7.3',
    install_requires=['lino'],
    tests_require=[],
    # pisa has a bug which makes it complain that "Reportlab Version
    # 2.1+ is needed!" when reportlab 3 is installed.
    # So we install reportlab 2.7 (the latest 2.x version)

    # beautifulsoup4, html5lib, reportlab and pisa are actually needed
    # only when you want to run the test suite, not for normal
    # operation.  Despite this they must be specified in
    # `install_requires`, not in `tests_require`, because the doctests
    # are run in the environment specified by `install_requires`.

    description="The documentation for Lino",
    license='BSD License',
    include_package_data=True,
    zip_safe=False,
    author='Luc Saffre',
    author_email='luc.saffre@gmail.com',
    url="http://www.lino-framework.org",
    #~ test_suite = 'lino_book.projects',
    test_suite='tests',
    classifiers="""\
  Programming Language :: Python
  Programming Language :: Python :: 2
  Programming Language :: Python :: 3
  Development Status :: 5 - Production/Stable
  Environment :: Web Environment
  Framework :: Django
  Intended Audience :: Developers
  Intended Audience :: System Administrators
  License :: OSI Approved :: BSD License
  Natural Language :: English
  Natural Language :: French
  Natural Language :: German
  Operating System :: OS Independent
  Topic :: Database :: Front-Ends
  Topic :: Home Automation
  Topic :: Office/Business
  Topic :: Software Development :: Libraries :: Application Frameworks""".splitlines())

if PY2:
    SETUP_INFO['install_requires'].append('reportlab<2.7')
else:
    SETUP_INFO['install_requires'].append('reportlab')

SETUP_INFO.update(long_description="""\

This is the main documentation tree about the Lino framework.  It
covers three software packages and contains example code to be used
for educational and testing purposes.

Central documentation is published at http://www.lino-framework.org

""")

SETUP_INFO.update(packages=[str(n) for n in """
lino_book
lino_book.projects
lino_book.projects.babel_tutorial
lino_book.projects.babel_tutorial.fixtures
lino_book.projects.dumps
lino_book.projects.dumps.fixtures
lino_book.projects.dumps.settings
lino_book.projects.belref
lino_book.projects.belref.fixtures
lino_book.projects.belref.settings
lino_book.projects.docs
lino_book.projects.docs.settings
lino_book.projects.estref
lino_book.projects.estref.settings
lino_book.projects.estref.tests
lino_book.projects.events
lino_book.projects.polly
lino_book.projects.polly.settings
lino_book.projects.polly.tests
lino_book.projects.20090714
lino_book.projects.20090717
lino_book.projects.20100126
lino_book.projects.20100127
lino_book.projects.20100206
lino_book.projects.20100212
lino_book.projects.20121124
lino_book.projects.chooser
lino_book.projects.example
lino_book.projects.nomti
lino_book.projects.properties
lino_book.projects.quantityfield
lino_book.projects.cms
lino_book.projects.cms.fixtures
lino_book.projects.cms.tests
lino_book.projects.crl
lino_book.projects.crl.fixtures
lino_book.projects.homeworkschool
lino_book.projects.homeworkschool.fixtures
lino_book.projects.homeworkschool.settings
lino_book.projects.i18n
lino_book.projects.igen
lino_book.projects.igen.tests
lino_book.projects.max
lino_book.projects.max.settings
lino_book.projects.min1
lino_book.projects.min1.settings
lino_book.projects.min2
lino_book.projects.min2.modlib
lino_book.projects.min2.modlib.contacts
lino_book.projects.min2.modlib.contacts.fixtures
lino_book.projects.min2.settings
lino_book.projects.min2.tests
""".splitlines() if n])

SETUP_INFO.update(message_extractors={
    'lino': [
        ('**/sandbox/**',        'ignore', None),
        ('**/cache/**',          'ignore', None),
        ('**.py',                'python', None),
        ('**/linoweb.js',        'jinja2', None),
        #~ ('**.js',                'javascript', None),
        ('**/config/**.html', 'jinja2', None),
        #~ ('**/templates/**.txt',  'genshi', {
        #~ 'template_class': 'genshi.template:TextTemplate'
        #~ })
    ],
})




# -*- coding: UTF-8 -*-
# Copyright 2012-2013 Luc Saffre
# License: BSD (see file COPYING for details)


def objects():

    from lino.history import blogger
    yield blogger.flush()

    import lino.history.luc201212
    yield blogger.flush()



"""The demo fixture for this tutorial.
"""
from django.conf import settings
from django.utils.timezone import make_aware
from datetime import datetime
from lino_book.projects.dumps.models import Foo

if settings.USE_TZ:
    def dt(*args):
        return make_aware(datetime(*args))
else:
    def dt(*args):
        return datetime(*args)


def objects():
    yield Foo(
        name="First",
        last_visit=dt(2016, 07, 02, 23, 55, 12))
    yield Foo(
        name="Last",
        last_visit=dt(2016, 07, 03, 0, 10, 23))



# -*- coding: UTF-8 -*-
# Copyright 2012-2016 Luc Saffre
# License: BSD (see file COPYING for details)
"""
Default settings for a :mod:`lino_book.projects.min2` application.
"""

from lino.projects.std.settings import *


class Site(Site):
    """The parent of all :mod:`lino_book.projects.min2` applications.
    """
    title = "Lino Mini 2"
    project_model = 'projects.Project'
    languages = 'en et'
    user_profiles_module = 'lino.modlib.office.roles'

    demo_fixtures = """std demo demo2 checkdata""".split()

    def get_installed_apps(self):
        yield super(Site, self).get_installed_apps()
        # yield 'lino.modlib.users'
        yield 'lino_xl.lib.excerpts'
        yield 'lino_book.projects.min2.modlib.contacts'
        yield 'lino_xl.lib.addresses'
        yield 'lino_xl.lib.reception'
        # yield 'lino.modlib.sepa'
        yield 'lino_xl.lib.notes'
        yield 'lino_xl.lib.projects'
        yield 'lino_xl.lib.humanlinks'
        yield 'lino_xl.lib.households'
        yield 'lino_xl.lib.extensible'
        yield 'lino_xl.lib.pages'
        yield 'lino.modlib.export_excel'
        yield 'lino_xl.lib.dupable_partners'
        yield 'lino.modlib.plausibility'
        yield 'lino.modlib.tinymce'
        yield 'lino.modlib.wkhtmltopdf'
        yield 'lino_xl.lib.appypod'
        yield 'lino.modlib.changes'




# -*- coding: UTF-8 -*-
# Copyright 2013-2014 Luc Saffre
# License: BSD (see file COPYING for details)

"""

"""


from __future__ import unicode_literals

#~ try:

from lino.projects.std.settings import *

#~ from django.utils.translation import ugettext_lazy as _


class Site(Site):

    title = "Lino Events"
    verbose_name = "Lino Events"
    #~ verbose_name = "Lino Cosi"
    #~ description = _("a Lino application to make Belgian accounting simple.")
    #~ version = "0.1"
    #~ url = "http://www.lino-framework.org/autodoc/lino.projects.cosi"
    #~ author = 'Luc Saffre'
    #~ author_email = 'luc.saffre@gmail.com'

    # demo_fixtures = 'std few_countries few_cities vor'.split()
    demo_fixtures = 'std demo vor'.split()

    languages = 'de fr nl'
    #~ languages = ['de','fr','nl']
    #~ languages = 'de fr et en'.split()

    def get_installed_apps(self):
        yield super(Site, self).get_installed_apps()
        yield 'lino.modlib.system'
        yield 'lino_xl.lib.countries'
        yield 'lino_xl.lib.events'


SITE = Site(globals())

#~ except Exception as e:
    #~ import traceback
    #~ traceback.print_exc(e)
    #~ sys.exit(1)
  #~
